.TH AUTO-ADMIN 1
.SH NAME    \" Section header
.PP

auto-admin \- Automated systems management tools

.SH SYNOPSIS
.PP
.nf 
.na 
auto-amd-local-setup
auto-amd-nfs-setup
auto-append-line search-string line file calling-program-name
auto-ask tag "question" default-answer
auto-clean-ports
auto-config-snd-driver
auto-disable-service rc.conf-name
auto-enable-compat32
auto-enable-passwdqc
auto-enable-procfs
auto-enable-service [-s rc.d-name] rc.conf-name calling-program-name
auto-fastest-mirror
auto-install-packages category/port [category/port ...]
auto-ipfw-gateway-setup public-interface local-interface
auto-kdm3-toggle on|off
auto-ldap-adduser [username]
auto-ldap-client-setup uri ou o cacert-file
auto-package-installed category/port
auto-replace-file new old
auto-service-enabled rc.conf-name
auto-set-suspend-on-lid
auto-update-port-framework category/port
auto-update-xorg.conf
auto-xdm-toggle on|off
.ad
.fi

\" Optional sections
.SH "PURPOSE"

.B auto-admin
is a set of simple tools for automating systems management.  The tools are
meant to be used in scripts that automate specific tasks, such as
desktop-installer and cluster-admin tools.

.SH AUTO-AMD-LOCAL-SETUP

.B auto-amd-local-setup

Configures AMD, the automount daemon, to mount local devices such as
DVDROMs and flash drives when specified directories are accessed.  The
access directories are those listed in /etc/fstab, minus /mnt. For example,
if /etc/fstab lists /mnt/dvdrom, then the dvdrom is actually automounted
and accessed by going to /dvdrom.

.SH AUTO-AMD-NFS-SETUP

.B auto-amd-nfs-setup

Configures AMD, the automount daemon, to mount remote NFS filesystems
automatically when specified directories are accessed.  The user is
prompted for information about the NFS server and the name of the
directory under which the server should be mounted.

.SH "AUTO-APPEND-LINE"

.B auto-append-line search-string line file calling-program-name

Appends 
.B line
to a text file if the file does not already contain
.B search-string
as a whole word.  ( Uses grep -w to prevent false positives such as
webcamd when searching for amd. )
If search-string is the empty string (''), line is used as the search
string.

A comment beginning with '#' is placed above the line stating that the
line was added by
.B calling-program-name
unless calling-program-name is "nocomment".  When calling auto-append-line
from another script, $0 is usually passed to calling-program-name.

Example:

Enable USB-serial adapters at boot time if they have not
already been explicitly enabled or disabled.

.na
auto-append-line uplcom_load 'uplcom_load="YES"' /boot/loader.conf $0
.ad

.SH AUTO-ASK

.B auto-ask tag "prompt" default-answer

Display
.B prompt
to the terminal and echo the response entered by the user to the standard
output.  Note that the prompt is send to the terminal device via a different
route so that it is not confused with the user input.  If the user enters
nothing (just presses enter), echo
.B default-answer
or the answer stored from a previous invocation with the same
.B tag.
Tags are stored in ./auto-ask-responses.txt, so a script using
.B auto-ask
must be run from the same directory in order to remember previous answers.
The
.B tag
may not contain any whitespace.

Example:

.na
resp=`auto-ask edit-xorg "Edit xorg.conf? (y/n)" n`
.ad

.SH AUTO-CLEAN-PORTS

.B auto-clean-ports

Run "make distclean" in all ports directories containing a work directory.
This can free a substantial amount of disk space after many ports have
been installed.

.SH AUTO-CONFIG-SND-DRIVER

.B auto-config-snd-driver

Auto-detect supported sound devices and add a load command to /boot/loader.conf
for the first device detected.  Does not currently support auto-detecting
multiple sound devices.

.SH AUTO-DISABLE-SERVICE

.B auto-disable-service rc.conf-name

Disable the service enabled by
.B <rc.conf-name>_enable="YES"
by altering the line in rc.conf.

.SH AUTO-ENABLE-COMPAT32

.B auto-enable-compat32

Enable 32-bit compatibility on 64-bit systems, as required for certain
applications.

.SH AUTO-ENABLE-PASSWDQC

.B auto-enable-passwdqc

Enable the PAM password quality control module, which requires users to set
secure local passwords.

.SH AUTO-ENABLE-PROCFS

.B auto-enable-procfs

Enable and mount /proc, which is required by some applications.

.SH AUTO-ENABLE-SERVICE

.B auto-enable-service [-s rc.d-name] rc.conf-name calling-program-name

Enable a service in rc.conf if it has not been explicitly enabled or
disabled (i.e. there is no line containing <rc.conf-name>_enable already
present).
Some ports unfortunately have rc.d scripts with a different name than
the service name in rc.conf.  If this is the case, specify the script
name following -s.  The -s flag must be the first argument.
A comment is placed above the line stating that the line was added by
.B calling-program-name.

Examples:

.nf
.na
# Add ntpd_enable="YES" to rc.conf and run /etc/rc.d/ntpd
auto-enable-service ntpd desktop-installer
# Add kerberos5_server_enable="YES" to rc.conf and run /etc/rc.d/kerberos
auto-enable-service -s kerberos kerberos5_server ad-client-setup
.ad
.fi

.SH AUTO-FASTEST-MIRROR

.B auto-fastest-mirror

Print the URL of the fastest mirror site for downloading packages. This
is normally used to set AUTO_PACKAGEROOT for auto-install-packages.

Example:

.na
export AUTO_PACKAGEROOT=`auto-fastest-mirror`
.ad

.SH AUTO-INSTALL-PACKAGES

.B auto-install-packages category/port [category/port ...]

Install
.B category/port
from binary package or from source.  If AUTO_BUILD_FROM_SOURCE is "yes", the
port is installed from source.  If AUTO_BUILD_FROM_SOURCE is "no"
or "fall-back", the port is installed from binary package using pkg_add -r,
using the main site, or the site specified by AUTO_PACKAGEROOT.  If
installing from binary package fails, and AUTO_BUILD_FROM_SOURCE is
"fall-back", an attempt is made to install from source.

Unlike pkg_add,
.B auto-install-packages
allows multiple packages to be installed in a single command, and
attempts to determine whether the package is already installed before
downloading/building it.

Example:

.na
export AUTO_PACKAGEROOT=`auto-fastest-mirror`
auto-install-packages net/samba print/cups
.ad

.SH AUTO-IPFW-GATEWAY-SETUP

.B auto-ipfw-gateway-setup public-interface local-interface

Configure the server as a firewall gateway using ipfw.  This installs
necessary software and a default set of firewall rules that allow ipfw
to operate efficiently.  ( ipfw can use a significant amount of CPU time
if not configured properly. )

Example:

.na
auto-ipfw-gateway-setup nfe0 nfe1
.ad

.SH AUTO-KDM3-TOGGLE

.B auto-kdm3-toggle on|off

Enable/disable KDM3 in /etc/ttys.

.SH AUTO-LDAP-ADDUSER

.B auto-ldap-adduser [username]

Add a local user who can authenticate logins using either local password or
the LDAP server configured by 
.B auto-ldap-client-setup.
If an LDAP
configuration is detected, the LDAP server is queried to validate the user
name and extract default information for creating the local account.

.SH AUTO-LDAP-CLIENT-SETUP

.B auto-ldap-client-setup uri ou o cacert-file

Configure the machine to allow users to authenticate SSH logins using
either LDAP or local passwords.  Additional login services besides SSH
can be configured by updating their entries in /etc/pam.d to resemble
/etc/pam.d/sshd.

Example:

.na
auto-ldap-client-setup ldap://ldap.my.domain people my.domain cacert.pem
.ad

.SH AUTO-PACKAGE-INSTALLED

.B auto-package-installed category/port

Check whether
.B category/port
is installed.  Exit status is 0 if installed, and non-zero otherwise.
In addition, a text message stating whether the port is installed is
printed to the standard output.

.SH AUTO-REPLACE-FILE

.B auto-replace-file new old

Back up the file "old" to "old.orig" and replace it with the file "new",
only if "new" and "old" differ.

Example:

.na
auto-replace-file /usr/local/etc/smb.conf my.smb.conf
.ad

.SH AUTO-SERVICE-ENABLED

.B auto-service-enabled rc.conf-name

Check whether
.B service
is enabled.  Exit status is 0 if enabled, and non-zero otherwise.

Example:

.nf
.na
if [ `auto-service-enabled cups` ]; then
    printf "CUPS is already enabled.\n"
fi
.ad
.fi

.SH AUTO-SET-SUSPEND-ON-LID

.B auto-set-suspend-on-lid S1|S2|S3|S4|S5|NONE

Configures laptop lid switch action to the specified ACPI mode.

.B Caution:
NONE
disables action when the laptop is closed, allowing the computer to
continue running.  This could lead to overheating and hardware damage.

Supported modes depend on the hardware and the available ACPI drivers.
S5 (shut down) is the most universally supported.

S3 (suspend to RAM) is generally considered the most desirable, but is
not supported on all hardware due to hardware capabilities or incomplete
drivers.

.SH AUTO-UPDATE-PORT-FRAMEWORK

.B auto-update-port-framework category/port

Rename ${PORTSDIR}/category/port to ${PORTSDIR}/category/port.`date`
and replace it with the latest port framework.

This should be used with
caution, as it might break dependencies for other ports.  If you are using
the RELEASE ports tree, note that this will bring the port out of sync with the
binary package.

.SH AUTO-UPDATE-XORG.CONF

.B auto-update-xorg.conf

Update /etc/X11/xorg.conf to match the current configuration.  The
X server must be restarted before the changes will take effect.  This
is used mainly after installing additional font packages.

.SH AUTO-XDM-TOGGLE

.B auto-xdm-toggle on|off

Enable/disable XDM in /etc/ttys.

.SH ENVIRONMENT
.nf
.na
AUTO_BUILD_FROM_SOURCE - Instruct auto-install-packages to install from source.
AUTO_PACKAGEROOT - Site from which binary packages are downloaded.
.ad
.fi

.SH BUGS
Please report bugs to the author and send patches in unified diff format.
(man diff for more information)

.SH AUTHOR
.nf
.na
J. Bacon
Acadix Consulting, LLC

